# Copyright 2025 The EasyDeL/eFormer Author @erfanzar (Erfan Zare Chavoshi).
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.


from logging import getLogger as _getLogger

_getLogger("jax.experimental.array_serialization.serialization").setLevel(40)

__version__ = "0.0.78"

__all__ = (
    "aparser",
    "common_types",
    "escale",
    "executor",
    "jaximus",
    "loggings",
    "mpric",
    "optimizers",
    "paths",
    "pytree",
    "serialization",
)
